@@ -8,7 +8,11 @@ usage = '''
 	
     python -m gif2ascii -f anime.gif -w 80
     python -m gif2ascii -f anime.gif --fit-terminal
-    python -m gif2ascii -f hehe.jpg -c ABCDEF -d 0.1
+    python -m gif2ascii -f john.jpg -c ABCDEF -d 0.1
+
+    Use with screenfetch
+
+    echo 'startline=0;fulloutput=($(python -m gif2ascii -f john.jpg -w 40 --screenfetch))' > /tmp/script.sh && screenfetch -E -a /tmp/script.sh
 
     github.com/shobhit99
 '''
@@ -20,6 +24,7 @@ parser.add_argument("-d", help="Frame delay between frames for gif", type=str, d
 parser.add_argument("-c", help="Characters to be used for ASCII output", type=str, default="108BRES")
 parser.add_argument("--fit-terminal", help="Fit entire terminal", action='store_true', default=False)
 parser.add_argument("--no-loop", help="Loop gif animation ", action='store_true', default=False)
+parser.add_argument("--screenfetch", help="Create template for screenfetch", action='store_true', default=False)
 
 args = parser.parse_args()
 
@@ -29,5 +34,6 @@ GifAscii(
     frame_delay=float(args.d),
     chars=args.c,
     fit_terminal=args.fit_terminal,
-    loop_gif=not args.no_loop
+    loop_gif=not args.no_loop,
+    screenfetch=args.screenfetch
 ).output()
